
# Slot: volume


volume of a book or music release in a collection/series or a published collection of journal issues in a serial publication

URI: [biolink:volume](https://w3id.org/biolink/vocab/volume)


## Domain and Range

[Publication](Publication.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [Article](Article.md)
 * [BookChapter](BookChapter.md)
 * [Serial](Serial.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | WIKIDATA_PROPERTY:P478 |

